# -*- coding: utf-8 -*-
# Part of Odoo. See LICENSE file for full copyright and licensing details.

from . import eu_account_map
from . import eu_tax_map
from . import eu_tag_map
from . import res_company
from . import res_config_settings
